# StableSketch/bctx.rb - 保存提醒

require 'sketchup.rb'

module StableSketch
  class CrashGuard
    def initialize_alert
      @last_unsaved_alert = nil
      @alert_active = false
      # 启动定时器，每3分钟检查一次
      UI.start_timer(180, true) do
        StableSketch.log_info("3分钟定时器触发，检查未保存模型", backup_dir)
        check_unsaved_model
      end
    end

    def check_unsaved_model
      StableSketch.log_info("检查未保存模型开始", backup_dir)
      model = Sketchup.active_model
      unless model
        StableSketch.log_warn("跳过检查：没有活动模型", backup_dir)
        return
      end

      StableSketch.log_info("当前模型路径：#{model.path.inspect}", backup_dir)
      if model.path.empty?
        StableSketch.log_warn("检测到未保存模型", backup_dir)

        # 检查是否已有提醒窗口活动，或上次提醒时间间隔是否足够
        if @alert_active || (@last_unsaved_alert && (Time.now - @last_unsaved_alert) < 300)
          StableSketch.log_info("未保存提醒跳过：窗口已打开或距离上次提醒不足5分钟", backup_dir)
          return
        end

        begin
          @alert_active = true  # 标记提醒窗口打开
          UI.messagebox("操，你模型没保存！\n赶紧存个档，不然崩溃了别怪我！")
          @last_unsaved_alert = Time.now
          @alert_active = false  # 窗口关闭后重置标记
          StableSketch.log_info("已提醒用户保存未保存的模型", backup_dir)
        rescue => e
          @alert_active = false  # 异常时重置标记
          StableSketch.log_error("提醒弹窗失败", e, backup_dir)
          puts "操，没保存，赶紧存档！"
          $stdout.flush
        end
      else
        StableSketch.log_info("模型已保存，路径：#{model.path}", backup_dir)
      end
    end
  end

  # 在模块加载时初始化提醒
  unless defined?(@@alert_initialized)
    CrashGuard.instance.initialize_alert
    @@alert_initialized = true
  end
end