# StableSketch/czgm.rb - 查找高模

require 'sketchup.rb'

module StableSketch
  class HighModelFinder
    def initialize
      @threshold = 100000  # 将阈值从10000改为100000
      find_high_models
    end

    def show_results
      # 在控制台输出调试信息
      puts "=== 高模检测结果 ==="
      puts "共找到 #{@high_models.size} 个高模"
      @high_models.each_with_index do |hm, i|
        name = hm[:entity].name || '未命名'
        puts "#{i+1}. #{name} (面数: #{hm[:faces]})"
      end
      puts "=================="

      # 调用显示窗口
      StableSketch::HighModelDisplay.show_results(@high_models)
    end

    def find_high_models
      model = Sketchup.active_model
      entities = model.entities
      @high_models = []
      
      entities.each do |entity|
        if entity.is_a?(Sketchup::ComponentInstance) || entity.is_a?(Sketchup::Group)
          faces = count_faces(entity)
          @high_models << {entity: entity, faces: faces} if faces > @threshold
        end
      end
      
      if @high_models.empty?
        UI.messagebox("未找到面数超过#{@threshold}的高模")
      else
        show_results
      end
    end

    def count_faces(entity)
      @processed_definitions ||= Set.new
      count = 0
      
      if entity.is_a?(Sketchup::ComponentInstance)
        definition = entity.definition
        unless @processed_definitions.include?(definition)
          @processed_definitions.add(definition)
          definition.entities.each do |e|
            if e.is_a?(Sketchup::Face)
              count += 1
            elsif e.is_a?(Sketchup::ComponentInstance) || e.is_a?(Sketchup::Group)
              count += count_faces(e)
            end
          end
        end
      elsif entity.is_a?(Sketchup::Group)
        entity.definition.entities.each do |e|
          if e.is_a?(Sketchup::Face)
            count += 1
          elsif e.is_a?(Sketchup::ComponentInstance) || e.is_a?(Sketchup::Group)
            count += count_faces(e)
          end
        end
      end
      
      count
    end

    private

    def jump_to_model(index)
      begin
        model = Sketchup.active_model
        entity = @high_models[index][:entity]
        model.selection.clear
        model.selection.add(entity)
        model.active_view.zoom(entity)
      rescue => e
        UI.messagebox("跳转失败: #{e.message}")
      end
    end
  end
end
