module StableSketch
  class HighModelDisplay
    def self.show_results(high_models)
      dialog = UI::WebDialog.new("高模检测结果", true, "HighModelDisplay", 450, 600, 150, 150, true)
      
      # 生成结果HTML字符串
      results_html = if high_models.empty?
        '<div class="no-models">未找到高模组件</div>'
      else
        # 添加一个计数器来追踪未命名模型的序号
        unnamed_count = 0
        
        items = high_models.each_with_index.map { |hm, i|
          if hm[:entity].name.to_s.empty?
            unnamed_count += 1
            name = "高面数模型#{unnamed_count}"
          else
            name = hm[:entity].name
          end
          
          "<div class='model-item' onclick='jumpToModel(#{i})'>" +
          "<span class='model-name'>#{i+1}. #{name}</span>" +
          "<span class='model-faces'>#{hm[:faces]} 个面</span>" +
          "</div>"
        }.join

        "<div class='summary'>共找到 #{high_models.size} 个高模组件</div>" +
        "<div class='model-list'>#{items}</div>"
      end

      # 直接将结果嵌入初始HTML
      dialog.set_html(<<-HTML)
<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <style>
    body {
      font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
      padding: 20px;
      background-color: #f8f9fa;
      color: #212529;
    }
    .header {
      margin-bottom: 20px;
    }
    h1 {
      font-size: 20px;
      font-weight: 600;
      color: #1a73e8;
      margin: 0;
    }
    .summary {
      background-color: #e8f0fe;
      padding: 12px 15px;
      border-radius: 6px;
      margin-bottom: 15px;
      font-size: 14px;
    }
    .model-list {
      max-height: 400px;
      overflow-y: auto;
      padding-right: 8px;
    }
    .model-item {
      display: flex;
      justify-content: space-between;
      padding: 10px 12px;
      margin-bottom: 8px;
      background-color: white;
      border-radius: 6px;
      box-shadow: 0 1px 2px rgba(0,0,0,0.05);
      transition: all 0.2s;
      cursor: pointer;
    }
    .model-item:hover {
      background-color: #e8f0fe;
      transform: translateY(-1px);
      box-shadow: 0 2px 4px rgba(0,0,0,0.1);
    }
    .model-name {
      font-weight: 500;
      color: #1a73e8;
    }
    .model-faces {
      color: #5f6368;
      font-size: 13px;
    }
  </style>
  <script>
    function jumpToModel(index) {
      window.location.href = 'skp:jumpToModel@' + index;
    }
    
    // 禁用右键菜单
    document.addEventListener('contextmenu', function(e) {
      e.preventDefault();
      return false;
    });
  </script>
</head>
<body>
  <div class="header">
    <h1>高模检测结果</h1>
  </div>
  <div id="results">
    #{results_html}
  </div>
</body>
</html>
      HTML

      # 添加跳转回调
      dialog.add_action_callback("jumpToModel") do |_, index|
        begin
          model = Sketchup.active_model
          entity = high_models[index.to_i][:entity]
          model.selection.clear
          model.selection.add(entity)
          model.active_view.zoom(entity)
        rescue => e
          UI.messagebox("跳转失败: #{e.message}")
        end
      end

      # 显示对话框
      dialog.show
      dialog
    end
  end
end
