require 'sketchup.rb'
require 'shellwords'
require 'win32ole' if Sketchup.platform == :platform_win

module StableSketch
  class CrashGuard
    def open_backup
      backup_path = self.class.backup_directory
      StableSketch.log_info("准备打开备份文件夹：#{backup_path}", backup_path)

      if backup_path.start_with?('\\\\')
        StableSketch.log_info("检测到网络路径：#{backup_path}", backup_path)
        UI.messagebox("网络路径需手动访问：#{backup_path}")
        return "备份文件夹打开失败：网络路径需手动访问"
      end

      unless Dir.exist?(backup_path)
        begin
          Dir.mkdir(backup_path)
          StableSketch.log_info("成功创建备份文件夹：#{backup_path}", backup_path)
        rescue => e
          StableSketch.log_error("无法创建备份文件夹：#{backup_path}", e, backup_path)
          UI.messagebox("操，无法创建备份文件夹：#{backup_path}\n错误：#{e.message}")
          return "备份文件夹打开失败：无法创建文件夹"
        end
      end

      success = if Sketchup.platform == :platform_win
        begin
          shell = WIN32OLE.new('Shell.Application')
          safe_path = backup_path.gsub('/', '\\')
          shell.ShellExecute('explorer.exe', safe_path, nil, 'open', 1)
          StableSketch.log_info("使用 ShellExecute 打开：#{safe_path}", backup_path)
          true
        rescue => e
          StableSketch.log_error("ShellExecute 失败，尝试回退方法", e, backup_path)
          system("start explorer #{Shellwords.escape(safe_path)}")
          $?.success?
        end
      else
        system("open #{Shellwords.escape(backup_path)}")
        $?.success?
      end

      if success
        StableSketch.log_info("文件夹已打开：#{backup_path}", backup_path)
        "备份文件夹已打开成功"
      else
        StableSketch.log_warn("文件夹打开失败：#{backup_path}", backup_path)
        "备份文件夹打开失败：未知错误"
      end
    end
  end
end