# StableSketch/gjl.rb - 工具栏

require 'sketchup.rb'

module StableSketch
  module Toolbar
    def self.create_toolbar
      toolbar = UI::Toolbar.new("稳定模式")
      guard = CrashGuard.instance
      
      log_message = "尝试创建工具栏：稳定模式"
      if RUBY_PLATFORM =~ /mswin|mingw/
        StableSketch.log_info(log_message.encode("UTF-8", invalid: :replace, undef: :replace), guard.backup_dir)
      else
        StableSketch.log_info(log_message, guard.backup_dir)
      end

      icons_dir = File.join(File.dirname(__FILE__), "icons")

      cmd_monitor = UI::Command.new("模型备份") { StableSketch.log_info("触发模型备份", guard.backup_dir); CrashGuard.instance.start_monitoring }
      cmd_monitor.small_icon = File.join(icons_dir, "mxbf.png")
      cmd_monitor.large_icon = File.join(icons_dir, "mxbf.png")
      cmd_monitor.tooltip = "启动自动备份监控"
      toolbar.add_item(cmd_monitor)

      cmd_face_count = UI::Command.new("实时面数统计") { StableSketch.log_info("触发实时面数统计", guard.backup_dir); StableSketch::FaceCounter.new }
      cmd_face_count.small_icon = File.join(icons_dir, "mscz.png")
      cmd_face_count.large_icon = File.join(icons_dir, "mscz.png")
      cmd_face_count.tooltip = "统计模型面数"
      toolbar.add_item(cmd_face_count)

      cmd_optimize = UI::Command.new("图形优化") { StableSketch.log_info("触发图形优化", guard.backup_dir); CrashGuard.instance.optimize_graphics }
      cmd_optimize.small_icon = File.join(icons_dir, "txyh.png")
      cmd_optimize.large_icon = File.join(icons_dir, "txyh.png")
      cmd_optimize.tooltip = "优化图形显示设置"
      toolbar.add_item(cmd_optimize)

      cmd_clean = UI::Command.new("清理模型") { StableSketch.log_info("触发清理模型", guard.backup_dir); CrashGuard.instance.check_model }
      cmd_clean.small_icon = File.join(icons_dir, "qhmx.png")
      cmd_clean.large_icon = File.join(icons_dir, "qhmx.png")
      cmd_clean.tooltip = "清理模型中的冗余数据"
      toolbar.add_item(cmd_clean)

      cmd_find = UI::Command.new("查找高模") { StableSketch.log_info("触发查找高模", guard.backup_dir); StableSketch::HighModelFinder.new }
      cmd_find.small_icon = File.join(icons_dir, "czgm.png")
      cmd_find.large_icon = File.join(icons_dir, "czgm.png")
      cmd_find.tooltip = "查找高面数模型"
      toolbar.add_item(cmd_find)

      cmd_soften = UI::Command.new("模型柔化") { StableSketch.log_info("触发模型柔化", guard.backup_dir); StableSketch::ModelSoftener.new }
      cmd_soften.small_icon = File.join(icons_dir, "mxrh.png")
      cmd_soften.large_icon = File.join(icons_dir, "mxrh.png")
      cmd_soften.tooltip = "柔化选中的模型（40°）"
      toolbar.add_item(cmd_soften)

      cmd_open_backup = UI::Command.new("打开备份") { StableSketch.log_info("触发打开备份", guard.backup_dir); CrashGuard.instance.open_backup }
      cmd_open_backup.small_icon = File.join(icons_dir, "dkbf.png")
      cmd_open_backup.large_icon = File.join(icons_dir, "dkbf.png")
      cmd_open_backup.tooltip = "打开备份文件夹"
      toolbar.add_item(cmd_open_backup)

      cmd_set_path = UI::Command.new("设置备份路径") { StableSketch.log_info("触发设置备份路径", guard.backup_dir); CrashGuard.set_backup_path }
      cmd_set_path.small_icon = File.join(icons_dir, "lj.png")
      cmd_set_path.large_icon = File.join(icons_dir, "lj.png")
      cmd_set_path.tooltip = "设置备份路径"
      toolbar.add_item(cmd_set_path)

      cmd_update = UI::Command.new("检查更新") { StableSketch.log_info("触发检查更新", guard.backup_dir); StableSketch::HotUpdateChecker.new.check_update }
      cmd_update.small_icon = File.join(icons_dir, "rgxgo.png")
      cmd_update.large_icon = File.join(icons_dir, "rgxgo.png")
      cmd_update.tooltip = "检查插件更新"
      toolbar.add_item(cmd_update)

      toolbar.show
      
      success_message = "工具栏创建成功：稳定模式"
      if RUBY_PLATFORM =~ /mswin|mingw/
        StableSketch.log_info(success_message.encode("UTF-8", invalid: :replace, undef: :replace), guard.backup_dir)
      else
        StableSketch.log_info(success_message, guard.backup_dir)
      end
    rescue => e
      StableSketch.log_error("工具栏创建失败", e, CrashGuard.default_backup_directory)
    end
  end
end