# StableSketch/log.rb
require 'sketchup.rb'

module StableSketch
  def self.sanitize_string(str)
    str.to_s.encode("UTF-8", invalid: :replace, undef: :replace, replace: "?")
  end

  def self.write_log(message, level, backup_path)
    backup_path ||= CrashGuard.default_backup_directory
    timestamp = Time.now.strftime('%H:%M:%S.%L')
    log_message = "[#{timestamp}] StableSketch [#{level}] ► #{sanitize_string(message)}"
    
    if RUBY_PLATFORM =~ /mswin|mingw/
      puts log_message.encode("UTF-8", invalid: :replace, undef: :replace, replace: "?")
    else
      puts log_message
    end
    $stdout.flush
    
    File.open(File.join(backup_path, "stable_sketch.log"), "a:UTF-8") { |f| f.puts(log_message) }
  rescue => e
    puts "[#{timestamp}] StableSketch [FATAL] ► 日志写入失败: #{sanitize_string(e.message)}"
    $stdout.flush
  end

  def self.log_info(message, backup_path)
    write_log(message, "INFO", backup_path)
  end

  def self.log_warn(message, backup_path)
    write_log(message, "WARN", backup_path)
  end

  def self.log_error(context, error, backup_path)
    backup_path ||= CrashGuard.default_backup_directory
    timestamp = Time.now.strftime('%H:%M:%S.%L')
    safe_context = sanitize_string(context)
    safe_message = sanitize_string(error.message)
    safe_backtrace = error.backtrace.take(5).map { |line| sanitize_string(line) }.join("\n")
    log_message = "[#{timestamp}] StableSketch [ERROR] ► #{safe_context}: #{safe_message}\n#{safe_backtrace}"
    
    if RUBY_PLATFORM =~ /mswin|mingw/
      puts log_message.encode("UTF-8", invalid: :replace, undef: :replace, replace: "?")
    else
      puts log_message
    end
    $stdout.flush
    
    File.open(File.join(backup_path, "stable_sketch.log"), "a:UTF-8") { |f| f.puts(log_message) }
  rescue => e
    puts "[#{timestamp}] StableSketch [FATAL] ► 错误日志写入失败: #{sanitize_string(e.message)}"
    $stdout.flush
  end
end