module StableSketch
  class CrashGuard
    def start_monitoring
      config_path = File.join(File.dirname(__FILE__), "lj.conf")
      backup_path = File.read(config_path).strip rescue ""

      if backup_path.empty?
        UI.messagebox("请先设置好 备份目录，再次启动")
        return "请先设置好 备份目录，再次启动"
      end

      if @monitoring_started
        StableSketch.log_info("监控已启动，无需重复执行", @backup_path)
        UI.messagebox("监控已启动，无需重复执行！")
        return "监控已启动，无需重复执行"
      end

      StableSketch.log_info("启动监控：设置定时器", @backup_path)
      UI.start_timer(300, true) { auto_save }
      @monitoring_started = true
      StableSketch.log_info("监控定时器已设置（仅备份）", @backup_path)

      begin
        UI.messagebox("监控已开！\n备份动态调整：小模型5分钟，中模型10分钟，大模型15分钟")
        "监控已启动"
      rescue => e
        StableSketch.log_error("UI.messagebox 失败", e, @backup_path)
        puts "监控已开！\n备份动态调整：小模型5分钟，中模型10分钟，大模型15分钟"
        $stdout.flush
        "监控已启动（UI提示失败）"
      end
    end

    def auto_save
      StableSketch.log_info("auto_save 开始执行", @backup_path)
      model = Sketchup.active_model
      unless model
        StableSketch.log_warn("自动备份跳过：没有活动模型", @backup_path)
        return
      end

      if model.path.empty?
        StableSketch.log_warn("模型未保存，无法备份", @backup_path)
        begin
          UI.messagebox("操，模型没保存，存个档再备份吧！")
          StableSketch.log_info("已提醒用户保存模型", @backup_path)
        rescue => e
          StableSketch.log_error("未保存提示失败", e, @backup_path)
          puts "操，模型没保存，存档去！"
          $stdout.flush
        end
        return
      end

      begin
        face_count = model.entities.grep(Sketchup::Face).size
        StableSketch.log_info("模型面数：#{face_count}", @backup_path)

        interval = if face_count < 10000
          300 # 小模型：5分钟
        elsif face_count <= 20000
          600 # 中模型：10分钟
        else
          900 # 大模型：15分钟
        end

        StableSketch.log_info("检查自动备份：面数 #{face_count}, 间隔 #{interval}秒, 时间差 #{(Time.now - @last_save).to_i}秒", @backup_path)

        if (Time.now - @last_save) > interval
          safe_title = model.title.gsub(/[\/:*?"<>|]/, "_").empty? ? "Untitled_#{Time.now.strftime('%Y%m%d_%H%M%S')}" : model.title
          filename = "Autosave_#{safe_title}_#{Time.now.strftime('%Y%m%d_%H%M%S')}.skp"
          backup_file = File.join(@backup_path, filename)

          Dir.mkdir(@backup_path) unless Dir.exist?(@backup_path)
          StableSketch.log_info("尝试保存备份到：#{backup_file}", @backup_path)
          success = model.save_copy(backup_file)
          if success && File.exist?(backup_file)
            @last_save = Time.now
            StableSketch.log_info("自动备份搞定：#{filename}", @backup_path)
          else
            StableSketch.log_warn("自动备份失败：文件未生成", @backup_path)
          end
        else
          StableSketch.log_info("自动备份跳过：时间未到", @backup_path)
        end
      rescue => e
        StableSketch.log_error("备份炸了", e, @backup_path)
      end
    end
  end
end
