#此文件需使用与保留
#为了后期优化功能和升级功能的，插件免费了需要知道是否还有用户在使用，我才有继续升级插件的动力
#止插件不记录信息和内容，只发个心跳包来记录用户信息
#--------------------------------
#代码功能说明：
#这是一个需要保留的重要文件，用于插件后续的功能优化和升级。
#由于插件现在是免费的，开发者希望通过心跳包了解插件的实际使用情况。
#特别强调插件不会记录任何用户内容或隐私信息，只会发送最基本的心跳包。
#开发者表明持续更新的动力来自于知道有用户在使用这个插件。
#--------------------------------
#这种实现方式：
#既保护了用户隐私(不记录具体内容)
#又让开发者能了解插件的活跃用户数
#是一种比较合理的免费插件维护方案
#--------------------------------
# This file needs to be kept and used
# For future feature optimization and upgrades. Since the plugin is free now, 
# I need to know if there are still users using it to have motivation to continue improving the plugin.
# The plugin does not record any information or content, it only sends a "heartbeat" packet 
# to track user information.
#--------------------------------
require 'sketchup.rb'
require 'net/http'
require 'uri'
require 'thread'
require 'securerandom'  # 确保 SecureRandom 可用

module StableSketch
  class RealTimeOnlineUsers
    # 配置常量
    HEARTBEAT_INTERVAL = 30  # 心跳间隔（秒）
    SERVER_URL = "http://su-api.cdsjcc.cn/StableSketch/zxrs.php"  # 更新为新服务器地址

    def initialize
      @backup_path = CrashGuard.instance&.backup_dir || CrashGuard.default_backup_directory
      @active = true
      @mutex = Mutex.new
      @persistent_id = load_or_generate_persistent_id
      start_monitoring
    end

    def start_monitoring
      StableSketch.log_info("用户启动，ID: #{@persistent_id}", @backup_path)
      send_heartbeat
      UI.start_timer(HEARTBEAT_INTERVAL, true) { heartbeat_task if @active }
    end

    private

    def load_or_generate_persistent_id
      # 使用固定的文件名，确保一台电脑只有一个 ID
      id_file = File.join(Sketchup.temp_dir, "stable_sketch_id.txt")
      if File.exist?(id_file)
        File.read(id_file).strip
      else
        id = SecureRandom.uuid
        File.write(id_file, id)
        id
      end
    end

    def send_heartbeat
      @mutex.synchronize do
        post_heartbeat
      end
    end

    def post_heartbeat
      uri = URI(SERVER_URL)
      params = { 'user_id' => @persistent_id, 'timestamp' => Time.now.to_i }
      # 移除日志输出: StableSketch.log_info("发送心跳到 #{SERVER_URL}，参数: #{params.inspect}", @backup_path)
      
      http = Net::HTTP.new(uri.host, uri.port)
      request = Net::HTTP::Post.new(uri.path)
      request.set_form_data(params)
      response = http.request(request)
      
      # 移除日志输出: StableSketch.log_info("服务器响应: #{response.code} - #{response.message} - #{response.body}", @backup_path)
      unless response.is_a?(Net::HTTPSuccess)
        raise "服务器请求失败: #{response.code} - #{response.message}"
      end
    rescue => e
      StableSketch.log_error("心跳发送失败: #{e.message}", e, @backup_path)
    end

    def heartbeat_task
      send_heartbeat
    rescue => e
      StableSketch.log_error("心跳任务失败", e, @backup_path)
    end

    def stop_monitoring
      @active = false
    end
  end
end

unless file_loaded?(__FILE__)
  StableSketch::RealTimeOnlineUsers.new
  file_loaded(__FILE__)
end
