module StableSketch
  class CrashGuard
    def optimize_graphics
      StableSketch.log_info("optimize_graphics 开始执行", @backup_path)
      model = Sketchup.active_model
      return unless model

      begin
        rendering = model.rendering_options
        # 简化日志输出，不再显示所有渲染选项键名
        StableSketch.log_info("图形优化中...", @backup_path)

        model.start_operation("优化图形样式", true)
        # 图形优化设置
        rendering['EdgeDisplayMode'] = 1
        rendering['EdgeType'] = 0
        rendering['DrawBackEdges'] = false
        rendering['DrawDepthQue'] = false
        rendering['ExtendLines'] = false
        rendering['DrawLineEnds'] = false
        
        # 关闭轮廓线和短横
        rendering['DrawHorizon'] = false if rendering.keys.include?('DrawHorizon')  # 关闭轮廓线
        rendering['DrawJunctionPoints'] = false if rendering.keys.include?('DrawJunctionPoints')  # 关闭短横
        rendering['JitterEdges'] = false if rendering.keys.include?('JitterEdges')  # 关闭手绘效果
        
        # 尝试使用其他可能的键名关闭轮廓线和短横
        rendering['DrawSilhouettes'] = false if rendering.keys.include?('DrawSilhouettes')  # 另一种轮廓线设置
        rendering['DrawProfilesOnly'] = false if rendering.keys.include?('DrawProfilesOnly')  # 可能的轮廓线设置
        rendering['DisplayInstanceAxes'] = false if rendering.keys.include?('DisplayInstanceAxes')  # 关闭轴线显示
        
        # 尝试更多可能的短横相关设置
        rendering['EndpointStyle'] = 0 if rendering.keys.include?('EndpointStyle')  # 设置端点样式为无
        rendering['ExtendEdges'] = false if rendering.keys.include?('ExtendEdges')  # 可能的短横相关设置
        rendering['DepthCue'] = false if rendering.keys.include?('DepthCue')  # 可能的短横相关设置
        
        # 简化日志输出，不再详细列出所有尝试的渲染选项
        
        # 尝试通过样式设置关闭轮廓线和短横
        begin
          style = model.styles.active_style
          if style
            style.uses_edge_profiles = false if style.respond_to?(:uses_edge_profiles=)
            style.uses_silhouettes = false if style.respond_to?(:uses_silhouettes=)
            style.uses_guides = false if style.respond_to?(:uses_guides=)
            style.uses_hidden_geometry = false if style.respond_to?(:uses_hidden_geometry=)
            style.uses_endpoints = false if style.respond_to?(:uses_endpoints=)  # 尝试关闭端点显示
            StableSketch.log_info("通过样式设置关闭轮廓线和短横", @backup_path)
          end
        rescue => style_error
          StableSketch.log_error("设置样式选项失败", style_error, @backup_path)
        end
        
        # 直接关闭阴影
        begin
          shadow_info = model.shadow_info
          shadow_info['DisplayShadows'] = false
          StableSketch.log_info("直接关闭阴影显示", @backup_path)
        rescue => shadow_direct_error
          StableSketch.log_error("直接设置阴影失败", shadow_direct_error, @backup_path)
        end
        
        # 尝试关闭其他可能影响性能的选项
        begin
          # 关闭动画过渡效果
          pages = model.pages
          # 遍历所有页面，将过渡时间设为0秒
          pages.each { |page| page.transition_time = 0 }
          StableSketch.log_info("已将所有场景页面过渡时间设为0秒", @backup_path)
        rescue => animation_error
          StableSketch.log_error("设置动画过渡时间失败", animation_error, @backup_path)
        end
        
        begin
          # 尝试关闭阴影显示
          if rendering.keys.include?('DisplayShadows')
            current_value = rendering['DisplayShadows']
            StableSketch.log_info("当前DisplayShadows值: #{current_value}", @backup_path)
            # 尝试不同的方式设置阴影
            rendering['DisplayShadows'] = 0 rescue nil
          end
        rescue => shadow_error
          StableSketch.log_error("设置阴影选项失败", shadow_error, @backup_path)
        end

        model.commit_operation
        model.active_view.refresh

        # 简化日志输出
        StableSketch.log_info("图形优化完成", @backup_path)

        begin
          UI.messagebox("图形优化完成！\n已关闭后边线、深粗线、出头、端点、轮廓线、短横和动画过渡，性能提升！")
          # 不再重复记录日志
        rescue => e
          StableSketch.log_error("UI.messagebox 失败", e, @backup_path)
          puts "图形优化完成！\n已关闭后边线、深粗线、出头、端点、轮廓线、短横和动画过渡，性能提升！"
          $stdout.flush
        end
      rescue => e
        StableSketch.log_error("图形优化失败", e, @backup_path)
        begin
          UI.messagebox("图形优化失败：#{e.message}")
        rescue => msg_e
          StableSketch.log_error("UI.messagebox 失败", msg_e, @backup_path)
          puts "图形优化失败：#{e.message}"
          $stdout.flush
        end
      end
    end
  end
end