module StableSketch
  class ZDJM
    def initialize
      @model = Sketchup.active_model
      @selection = @model.selection
      @processed_definitions = Set.new
    end
    
    # 递归统计面数（组件去重）
    def count_faces_recursive(entities)
      face_count = 0
      entities.each do |entity|
        if entity.is_a?(Sketchup::Face) && entity.visible?
          face_count += 1
        elsif entity.is_a?(Sketchup::ComponentInstance)
          definition = entity.definition
          unless @processed_definitions.include?(definition)
            @processed_definitions.add(definition)
            face_count += count_faces_recursive(definition.entities)
          end
        elsif entity.is_a?(Sketchup::Group)
          face_count += count_faces_recursive(entity.entities)
        end
      end
      face_count
    end
    
    def reduce_faces(ratio)
      @processed_definitions.clear
      @model.definitions.each do |definition|
        face_count = count_faces_recursive(definition.entities)
        next unless face_count > 100000
        
        definition.entities.grep(Sketchup::Face).each_with_index do |face, index|
          next if index % (1/ratio).to_i != 0
          face.erase!
        end
      end
    end

    def check_high_poly_components
      return if @selection.empty?
      
      @selection.each do |entity|
        next unless entity.is_a?(Sketchup::Group) || entity.is_a?(Sketchup::ComponentInstance)
        
        # 计算面数
        face_count = 0
        entity.definition.entities.each do |e|
          face_count += 1 if e.is_a?(Sketchup::Face)
        end
        
        puts "检测到组件面数: #{face_count}"
        next unless face_count > 100000
        
        puts "警告: 发现高面数模型: #{face_count}面"
        
        # 获取组件边界框中心点
        bounds = entity.bounds
        center = bounds.center
        
        # 在中心点右侧1米处创建1米大小的红色立方体
        point = center.offset(Geom::Vector3d.new(1.m, 0, 0))
        cube = @model.active_entities.add_group
        
        face = cube.entities.add_face([
          point,
          point + [1.m, 0, 0],
          point + [1.m, 1.m, 0],
          point + [0, 1.m, 0]
        ])
        face.pushpull(1.m)
        
        # 设置红色材质
        material = @model.materials.add('Warning')
        material.color = Sketchup::Color.new(255, 0, 0)
        cube.material = material
      end
    end
  end
end