# StableSketch_Pro.rb - 主加载文件

require 'sketchup.rb'
require 'extensions.rb'

# 首先加载 log.rb，确保日志方法可用
load "StableSketch/log.rb"
# 加载其他核心模块（移除 lj.rb 的提前加载）
load "StableSketch/dkbf.rb"
load "StableSketch/gjl.rb"

module StableSketch
  VERSION = "5.6.2025".freeze
  PLUGIN_NAME = "稳定模式"
  PLUGIN_AUTHOR = '詹广权'.freeze

  unless file_loaded?(__FILE__)
    SUBMODULES = [
      "StableSketch/lj.rb",     # 调用路径（已提前）
      "StableSketch/mxbf.rb",   # 模型备份（自动备份）
      "StableSketch/mscz.rb",   # 实时面数显示计算
      "StableSketch/txyh.rb",   # 图形优化
      "StableSketch/qhmx.rb",   # 清理模型
      "StableSketch/czgm.rb",   # 查找高模
      "StableSketch/czgmck.rb", # 查找高模显示窗口
      "StableSketch/mxrh.rb",   # 模型柔化
      "StableSketch/bctx.rb",   # 保存提醒
      "StableSketch/dkbf.rb",   # 打开备份
      "StableSketch/rgxgo.rb",  # 热更新插件
      "StableSketch/gjl.rb",    # 工具栏
      "StableSketch/rsoo.rb"    # 实时当前人数
    ]

    UI.start_timer(1, false) do
      SUBMODULES.each do |file|
        begin
          load file
          log_info("加载子模块成功：#{file}", CrashGuard.default_backup_directory)
        rescue LoadError => e
          log_error("加载子模块失败：#{file}", e, CrashGuard.default_backup_directory)
        end
      end

      extension = SketchupExtension.new(PLUGIN_NAME, __FILE__)
      extension.description = "终极防崩溃解决方案，适配SU 2024 & 2025 | 作者官网：cdsjcc.cn"
      extension.version = VERSION
      extension.creator = PLUGIN_AUTHOR
      extension.copyright = "© 2024-2025 StableSketch Team | 詹广权用皮靶抽AI写出来的插件"
      Sketchup.register_extension(extension, true)
      file_loaded(__FILE__)

      StableSketch::UIAdapter.create_menu
      StableSketch::Toolbar.create_toolbar
    end
  end

  module UIAdapter
    def self.create_menu
      guard = CrashGuard.instance
      StableSketch.log_info("尝试创建顶层菜单：稳定模式", guard.backup_dir)
      
      menu = UI.menu
      submenu = menu.add_submenu("稳定模式")
      StableSketch.log_info("稳定模式顶层菜单创建成功", guard.backup_dir)
      
      submenu.add_item("🔄 模型备份") { StableSketch.log_info("触发模型备份", guard.backup_dir); CrashGuard.instance.start_monitoring }
      submenu.add_item("📊 实时面数统计") { StableSketch.log_info("触发实时面数统计", guard.backup_dir); StableSketch::FaceCounter.new }
      submenu.add_item("🎮 图形优化") { StableSketch.log_info("触发图形优化", guard.backup_dir); CrashGuard.instance.optimize_graphics }
      submenu.add_item("🧹 清理模型") { StableSketch.log_info("触发清理模型", guard.backup_dir); CrashGuard.instance.check_model }
      submenu.add_item("🔍 查找高模") { StableSketch.log_info("触发查找高模", guard.backup_dir); StableSketch::HighModelFinder.new }
      submenu.add_item("🌿 模型柔化") { StableSketch.log_info("触发模型柔化", guard.backup_dir); StableSketch::ModelSoftener.new }
      submenu.add_item("📂 打开备份") { StableSketch.log_info("触发打开备份", guard.backup_dir); CrashGuard.instance.open_backup }
      submenu.add_item("⚙️ 设置备份路径") { StableSketch.log_info("触发设置备份路径", guard.backup_dir); CrashGuard.set_backup_path }
      submenu.add_item("🌐 检查更新") { StableSketch.log_info("触发检查更新", guard.backup_dir); StableSketch::HotUpdateChecker.new.check_update }
    rescue => e
      StableSketch.log_error("菜单创建失败", e, CrashGuard.default_backup_directory)
    end
  end

  module Toolbar
    def self.create_toolbar
      StableSketch::Toolbar.create_toolbar
    end
  end
end
